@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 """Check the MANIFEST.in file in a Python source package for completeness.
 
 This script works by building a source distribution archive (by running
@@ -37,7 +37,7 @@ except ImportError:
     import configparser as ConfigParser
 
 
-__version__ = '0.10'
+__version__ = '0.11'
 __author__ = 'Marius Gedminas <marius@gedmin.as>'
 __licence__ = 'GPL v2 or later' # or ask me for MIT
 __url__ = 'https://github.com/mgedmin/check-manifest'
@@ -421,6 +421,8 @@ def check_manifest(source_tree='.', create=False, update=False):
         info_begin("copying source files to a temporary directory")
         with mkdtemp('-sources') as tempsourcedir:
             copy_files(source_files, tempsourcedir)
+            if os.path.exists('MANIFEST.in') and 'MANIFEST.in' not in source_files:
+                copy_files(['MANIFEST.in'], tempsourcedir)
             info_begin("building an sdist")
             with cd(tempsourcedir):
                 with mkdtemp('-sdist') as tempdir:
